==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Datos de contacto de empresa"

, "Organisation / Unit"
: "Organización / Unidad"

, "Business Address"
: "Dirección de la empresa"

, "Email"
: "Email"

, "Telephone Work"
: "Teléfono de trabajo"

, "Telephone Cellphone"
: "Teléfono celular"

, "Telephone Car"
: "Teléfono del automóvil"

, "Telephone Fax"
: "Teléfono Fax"

, "Telephone Page"
: "Página del teléfono"

, "URL"
: "URL"

, "Role"
: "Cargo"

, "Room"
: "Sala"

, "Assistant"
: "Asistente"

, "Assistant Telephone"
: "Teléfono del asistente"

, "Private Contact Data"
: "Datos de contacto privados"

, "Private Address"
: "Dirección privada"

, "Email Home"
: "Email doméstico"

, "Telephone Home"
: "Teléfono del hogar"

, "Telephone Cellphone Private"
: "Teléfono Celular Privado"

, "Telephone Fax Home"
: "Teléfono Fax Doméstico"

, "URL Home"
: "URL doméstico"

, "Other Data"
: "Otra Información"

, "Birthday"
: "Cumpleaños"

, "Job Title"
: "Nombre del Cargo"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Listas"

]
, "Percent"
: ""

, "Description"
: "Descripción"

, "Members"
: ""

, "Type"
: "Tipo"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Libreta de direcciones"
 ,"Libretas de direcciones"

]
, "Contact, Contacts"
: [
  "Contacto"
 ,"Contactos"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "País"

, "City"
: "Ciudad"

, "Postalcode"
: "Código Postal"

, "Region"
: "Región"

, "Street"
: "Calle"

, "Street 2"
: "Dirección 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "País (privado)"

, "City (private)"
: "Ciudad (privado)"

, "Postalcode (private)"
: "Código Postal (privado)"

, "Region (private)"
: "Región (privado)"

, "Street (private)"
: "Calle (privado)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (privado)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Nota"

, "Last Name"
: "Apellidos"

, "Display Name"
: "Nombre a Mostrar"

, "Full Name"
: "Nombre Completo"

, "First Name"
: "Nombre"

, "Middle Name"
: "Segundo Nombre"

, "Title"
: "Título"

, "Suffix"
: "Sufijo"

, "Company"
: "Compañía"

, "Unit"
: "Unidad"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Descripción del Cargo"

, "Salutation"
: "Trato"

, "syncBackendIds"
: ""

, "Car phone"
: "Teléfono del Automóvil"

, "Mobile"
: "Móvil"

, "Mobile (private)"
: "Celular (privado)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privado)"

, "Phone (private)"
: "Fono (privado)"

, "Pager"
: "Buscapersonas"

, "Phone"
: "Teléfono"

, "Timezone"
: "Zona Horaria"

, "Web"
: "Web"

, "URL (private)"
: "URL (privado)"

, "Label"
: ""

, "Lists"
: "Listas"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Información de Contacto"

, "Company Address"
: "Dirección de la Empresa"

, "New Contact"
: "Nuevo Contacto"

, "ID"
: ""

, "Name"
: "Nombre"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importar contactos"

, "Contact of a user account"
: "Contacto de una cuenta de usuario"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privado"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Etiquetas"

, "List Roles"
: ""

, "Street (Company Address)"
: "Calle (Dirección de la Empresa)"

, "Street 2 (Company Address)"
: "Calle 2 (Dirección de la Empresa)"

, "City (Company Address)"
: "Ciudad (Dirección de la Empresa)"

, "Region (Company Address)"
: "Región (Dirección de la Empresa)"

, "Postal Code (Company Address)"
: "Código Postal (Dirección de la Empresa)"

, "Country (Company Address)"
: "País (Dirección de la Empresa)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Calle (Dirección privada)"

, "Street 2 (Private Address)"
: "Calle 2 (Dirección privada)"

, "City (Private Address)"
: "Ciudad (Dirección privada)"

, "Region (Private Address)"
: "Región (Dirección privada)"

, "Postal Code (Private Address)"
: "Código Postal (Dirección privada)"

, "Country (Private Address)"
: "País (Dirección privada)"

, "Company Communication"
: "Comunicación Empresarial"

, "Private Communication"
: "Comunicación Privada"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privado)"

, "Web (private)"
: "Web (privado)"

, "Contacts"
: "Contactos"

, "Addressbooks"
: "Libreta de direcciones"

, "User Account"
: "Cuenta de Usuario"

, "Quick Search"
: "Búsqueda Rápida"

, "Postal Code"
: "Código Postal"

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: "Creado por"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Escribir descripción"

, "{0} must be given"
: ""

, "Member of List"
: "Miembro de la Lista"

, "Map"
: "Mapa"

, "Company address"
: "Dirección de la Empresa"

, "Private address"
: "Dirección privada"

, "CardDAV URL"
: "CardDAV URL"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Información Personal"

, "Parse address"
: "Analizar dirección"

, "Print contact"
: ""

, "Paste address"
: "Pegar dirección"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Finalizado modo token"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Todos los contactos"

, "Default Addressbook"
: "Libreta de Contactos Predefinida"

, "The default addressbook for new contacts"
: "La libreta de dirección predefinida para nuevos contactos"

, "Default Favorite"
: "Favorito por defecto"

, "The default favorite which is loaded on addressbook startup"
: "El favorito por defecto se cargará al iniciar la Libreta de direcciones"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: "Todos los contactos"

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Marcar campo contacto duplicado"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Estos campos se comprueban cuando se crea un nuevo contacto. Si se encuentra un registro con los mismos datos en los campos, se lanzada una aviso de duplicado."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Saludos al contacto disponibles"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Saludos disponibles al contacto. Tenga en cuenta que los valores adicionales podrían afectar a otros sistemas de libretas de direcciones en la exportación o la sincronización."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Reglas de análisis para direcciones"

, "Path to a XML file with address parsing rules."
: "Ruta de acceso a un archivo XML con las reglas de análisis de direcciones."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importar Contactos VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importar lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contactos importados el ###CURRENTDATE### a las ###CURRENTTIME### por ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Alemán"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importar Contactos desde Libreta de direcciones de Outlook"

, "Contact CSV import from mac address book"
: "Importar Contactos desde Libreta de direcciones de MAC"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importar Contactos desde Libreta de direcciones de Google"

, "manage shared addressbooks"
: "administrar libretas de direcciones compartidas"

, "Create new shared addressbook folders"
: "Crear nuevas libretas de direcciones compartidas"

, "manage shared addressbook favorites"
: "administrar libretas de direcciones compartidas favoritas"

, "Create or update shared addressbook favorites"
: "Crear o actualizar libretas de direcciones compartidas favoritas"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "Libreta de direcciones de %s's"

, "All contacts I have read grants for"
: "Todos los contactos que he ofrecido subvenciones para"

, "My company"
: "Mi empresa"

, "All coworkers in my company"
: "Todos mis compañeros en la empresa"

, "My contacts"
: "Mis contactos"

, "All contacts in my Addressbooks"
: "Todos los contactos en mi libreta de direcciones"

, "Last modified by me"
: "Última modificación por mi"

, "All contacts that I have last modified"
: "Todos los contactos que he modificado anteriormente"

, "Internal Contacts"
: "Contactos Internos"

, "List"
: "Lista"

, "Addressbook"
: "Libreta de direcciones"

, "Contact"
: "Contacto"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Mapa"

, "Preferred Address"
: ""

, "Personal Information"
: "Información Personal"

, "Salutation"
: "Trato"

, "Title"
: "Título"

, "Short Name"
: ""

, "First Name"
: "Nombre"

, "Middle Name"
: "Segundo Nombre"

, "Last Name"
: "Apellidos"

, "Company"
: "Compañía"

, "Unit"
: "Unidad"

, "Display Name"
: "Nombre a Mostrar"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Nombre del Cargo"

, "Birthday (private)"
: ""

, "Contact Information"
: "Información de Contacto"

, "Phone"
: "Teléfono"

, "Mobile"
: "Móvil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Fono (privado)"

, "Mobile (private)"
: "Celular (privado)"

, "Fax (private)"
: "Fax (privado)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privado)"

, "Web"
: "Web"

, "Company Address"
: "Dirección de la Empresa"

, "Street"
: "Calle"

, "Street 2"
: "Dirección 2"

, "Region"
: "Región"

, "Postal Code"
: "Código Postal"

, "City"
: "Ciudad"

, "Country"
: "País"

, "Private Address"
: "Dirección privada"

, "Description"
: "Descripción"

, "Enter description"
: "Escribir descripción"

, "Groups"
: ""

, "Parse address"
: "Analizar dirección"

, "Print contact"
: ""

, "Paste address"
: "Pegar dirección"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Finalizado modo token"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Contacto"
 ,"Contactos"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "CardDAV URL"

, "New Contact"
: "Nuevo Contacto"

, "Addressbook, Addressbooks"
: [
  "Libreta de direcciones"
 ,"Libretas de direcciones"

]
, "ID"
: ""

, "Name"
: "Nombre"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Privado"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Sufijo"

, "Birthday"
: "Cumpleaños"

, "Job Role"
: "Descripción del Cargo"

, "Room"
: "Sala"

, "Street (Company Address)"
: "Calle (Dirección de la Empresa)"

, "Street 2 (Company Address)"
: "Calle 2 (Dirección de la Empresa)"

, "City (Company Address)"
: "Ciudad (Dirección de la Empresa)"

, "Region (Company Address)"
: "Región (Dirección de la Empresa)"

, "Postal Code (Company Address)"
: "Código Postal (Dirección de la Empresa)"

, "Country (Company Address)"
: "País (Dirección de la Empresa)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Calle (Dirección privada)"

, "Street 2 (Private Address)"
: "Calle 2 (Dirección privada)"

, "City (Private Address)"
: "Ciudad (Dirección privada)"

, "Region (Private Address)"
: "Región (Dirección privada)"

, "Postal Code (Private Address)"
: "Código Postal (Dirección privada)"

, "Country (Private Address)"
: "País (Dirección privada)"

, "Company Communication"
: "Comunicación Empresarial"

, "Private Communication"
: "Comunicación Privada"

, "Web (private)"
: "Web (privado)"

, "Contacts"
: "Contactos"

, "Addressbooks"
: "Libreta de direcciones"

, "User Account"
: "Cuenta de Usuario"

, "Quick Search"
: "Búsqueda Rápida"

, "Type"
: "Tipo"

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: "Creado por"

, "List, Lists"
: [
  "Lista"
 ,"Listas"

]
, "Lists"
: "Listas"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Importar contactos"

, "Contact of a user account"
: "Contacto de una cuenta de usuario"

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Etiquetas"

, "Full Name"
: "Nombre Completo"

, "Postalcode"
: "Código Postal"

, "Street (private)"
: "Calle (privado)"

, "City (private)"
: "Ciudad (privado)"

, "Region (private)"
: "Región (privado)"

, "Postalcode (private)"
: "Código Postal (privado)"

, "Country (private)"
: "País (privado)"

, "Email"
: "Email"

, "Car phone"
: "Teléfono del Automóvil"

, "Pager"
: "Buscapersonas"

, "Email (private)"
: "Email (privado)"

, "URL (private)"
: "URL (privado)"

, "Note"
: "Nota"

, "Timezone"
: "Zona Horaria"

, "Geo"
: "Geo"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Dirección de la Empresa"

, "Private address"
: "Dirección privada"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Todos los contactos"

, "Default Addressbook"
: "Libreta de Contactos Predefinida"

, "The default addressbook for new contacts"
: "La libreta de dirección predefinida para nuevos contactos"

, "Default Favorite"
: "Favorito por defecto"

, "The default favorite which is loaded on addressbook startup"
: "El favorito por defecto se cargará al iniciar la Libreta de direcciones"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Marcar campo contacto duplicado"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Estos campos se comprueban cuando se crea un nuevo contacto. Si se encuentra un registro con los mismos datos en los campos, se lanzada una aviso de duplicado."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Saludos al contacto disponibles"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Saludos disponibles al contacto. Tenga en cuenta que los valores adicionales podrían afectar a otros sistemas de libretas de direcciones en la exportación o la sincronización."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Reglas de análisis para direcciones"

, "Path to a XML file with address parsing rules."
: "Ruta de acceso a un archivo XML con las reglas de análisis de direcciones."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "Libreta de direcciones de %s's"

, "Business Contact Data"
: "Datos de contacto de empresa"

, "Organisation / Unit"
: "Organización / Unidad"

, "Business Address"
: "Dirección de la empresa"

, "Telephone Work"
: "Teléfono de trabajo"

, "Telephone Cellphone"
: "Teléfono celular"

, "Telephone Car"
: "Teléfono del automóvil"

, "Telephone Fax"
: "Teléfono Fax"

, "Telephone Page"
: "Página del teléfono"

, "URL"
: "URL"

, "Role"
: "Cargo"

, "Assistant"
: "Asistente"

, "Assistant Telephone"
: "Teléfono del asistente"

, "Private Contact Data"
: "Datos de contacto privados"

, "Email Home"
: "Email doméstico"

, "Telephone Home"
: "Teléfono del hogar"

, "Telephone Cellphone Private"
: "Teléfono Celular Privado"

, "Telephone Fax Home"
: "Teléfono Fax Doméstico"

, "URL Home"
: "URL doméstico"

, "Other Data"
: "Otra Información"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importar Contactos desde Libreta de direcciones de Outlook"

, "Contact CSV import from mac address book"
: "Importar Contactos desde Libreta de direcciones de MAC"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Alemán"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importar Contactos VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importar lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contactos importados el ###CURRENTDATE### a las ###CURRENTTIME### por ###USERFULLNAME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importar Contactos desde Libreta de direcciones de Google"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Contactos Internos"

, "All contacts I have read grants for"
: "Todos los contactos que he ofrecido subvenciones para"

, "My company"
: "Mi empresa"

, "All coworkers in my company"
: "Todos mis compañeros en la empresa"

, "My contacts"
: "Mis contactos"

, "All contacts in my Addressbooks"
: "Todos los contactos en mi libreta de direcciones"

, "Last modified by me"
: "Última modificación por mi"

, "All contacts that I have last modified"
: "Todos los contactos que he modificado anteriormente"

, "All Contacts"
: "Todos los contactos"

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "administrar libretas de direcciones compartidas"

, "Create new shared addressbook folders"
: "Crear nuevas libretas de direcciones compartidas"

, "manage shared addressbook favorites"
: "administrar libretas de direcciones compartidas favoritas"

, "Create or update shared addressbook favorites"
: "Crear o actualizar libretas de direcciones compartidas favoritas"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Industry"
: ""

, "Contact"
: "Contacto"

, "Addressbook"
: "Libreta de direcciones"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Lista"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
